SystemOrganization addCategory: #'Seaside-Tests-Session'!

WARegistryKeyHandlingTest subclass: #WAApplicationKeyHandlingTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAApplicationKeyHandlingTest class methodsFor: 'testing' stamp: 'jf 1/30/2009 13:30'!
shouldInheritSelectors
	^ true! !

!WAApplicationKeyHandlingTest methodsFor: 'private' stamp: 'jok 3/22/2010 11:53'!
assertDefault: aResponse
	"Instead of returning 404 on a default request as WARegistry does, WAApplication creates a new
	Session and dispatches to it."
	self assert: registry cache size = (registrySize + 1).
	self assert: aResponse status = 200.
	self assert: (aResponse contents beginsWithSubCollection: 'start:')! !

!WAApplicationKeyHandlingTest methodsFor: 'private' stamp: 'pmm 9/5/2009 12:23'!
createRegistry
	^ WADispatcher new
		register: (WAApplication new
			preferenceAt: #sessionClass put: WATestSession;
			yourself)
		at: self registryName! !

!WAApplicationKeyHandlingTest methodsFor: 'private' stamp: 'jf 1/30/2009 13:16'!
fieldName
	^ '_s'! !

!WAApplicationKeyHandlingTest methodsFor: 'private' stamp: 'pmm 8/13/2010 13:59'!
registerNewHandler
	^ registry register: WATestNoopSessionHandler new! !

!WAApplicationKeyHandlingTest methodsFor: 'tests' stamp: 'pmm 7/17/2011 21:20'!
testFieldNoCookieHandlerAbsent
	"There is a key in the URL, no cookie, but handler specified by key does not exist"
	
	| response context |
	registry := self createRegistryWithCookiesEnabled.
	context := self createRequestContextWithFieldKey: '123' cookieKey: nil.
	response := self dispatch: context to: registry.
	
	self assertNoCookies: response.
	self assertExpired: response! !

!WAApplicationKeyHandlingTest methodsFor: 'tests' stamp: 'pmm 7/17/2011 13:01'!
testFieldNoCookieHandlerPresent
	"There is a key in the URL but no cookie. The handler specified by key exists."
	
	| response context key |
	registry := self createRegistryWithCookiesEnabled.
	key := self registerNewHandler.
	context := self createRequestContextWithFieldKey: key cookieKey: nil.
	response := self dispatch: context to: registry.
	
	self assertCookieAddition: response key: key.
	self assertDispatched: response! !

!WAApplicationKeyHandlingTest methodsFor: 'tests' stamp: 'pmm 7/17/2011 21:21'!
testMatchingHandlerAbsent
	"There is a key in the URL and a cookie and the values match. However, the handler specified by key does not exist."
	
	| response context |
	registry := self createRegistryWithCookiesEnabled.
	context := self createRequestContextWithFieldKey: '123' cookieKey: '123'.
	response := self dispatch: context to: registry.
	
	self assertCookieDeletion: response.
	self assertExpired: response! !

!WAApplicationKeyHandlingTest methodsFor: 'tests' stamp: 'pmm 7/17/2011 21:21'!
testMatchingHandlerPresent
	"There is a key in the URL and a cookie and the values match. The handler specified by key exists."
	
	| response context key |
	registry := self createRegistryWithCookiesEnabled.
	key := self registerNewHandler.
	context := self createRequestContextWithFieldKey: key cookieKey: key.
	response := self dispatch: context to: registry.
	
	self assertNoCookies: response.
	self assertDispatched: response! !

!WAApplicationKeyHandlingTest methodsFor: 'tests' stamp: 'pmm 7/17/2011 13:04'!
testMismatchingWithBothHandlers
	"There is a key in the URL and a cookie but values do not match.
	Both keys have registered handlers associated with them."
	
	| response context urlKey cookieKey |
	registry := self createRegistryWithCookiesEnabled.
	urlKey := self registerNewHandler.
	cookieKey := self registerNewHandler.
	context := self createRequestContextWithFieldKey: urlKey cookieKey: cookieKey.
	response := self dispatch: context to: registry.
	
	self assertCookieAddition: response key: urlKey.
	self assertDispatched: response! !

!WAApplicationKeyHandlingTest methodsFor: 'tests' stamp: 'pmm 7/17/2011 21:22'!
testMismatchingWithCookieHandler
	"There is a key in the URL and a cookie but values do not match.
	There is no handler registered at the URL key but there is one at the cookie key."
	
	| response context key |
	registry := self createRegistryWithCookiesEnabled.
	key := self registerNewHandler.
	context := self createRequestContextWithFieldKey: '123' cookieKey: key.
	response := self dispatch: context to: registry.
	
	self assertNoCookies: response.
	self assertExpired: response! !

!WAApplicationKeyHandlingTest methodsFor: 'tests' stamp: 'pmm 7/17/2011 21:22'!
testMismatchingWithNoHandlers
	"There is a key in the URL and a cookie but values do not match.
	There is no handler registered at either key."
	
	| response context |
	registry := self createRegistryWithCookiesEnabled.
	context := self createRequestContextWithFieldKey: '123' cookieKey: '456'.
	response := self dispatch: context to: registry.
	
	self assertNoCookies: response.
	self assertExpired: response! !

!WAApplicationKeyHandlingTest methodsFor: 'tests' stamp: 'pmm 7/17/2011 12:52'!
testMismatchingWithUrlHandler
	"There is a key in the URL and a cookie but values do not match.
	There is a handler registered at the URL key but not at the cookie key."
	
	| response context key |
	registry := self createRegistryWithCookiesEnabled.
	key := self registerNewHandler.
	context := self createRequestContextWithFieldKey: key cookieKey: '123'.
	response := self dispatch: context to: registry.
	
	self assertCookieAddition: response key: key.
	self assertDispatched: response! !

!WAApplicationKeyHandlingTest methodsFor: 'tests' stamp: 'pmm 7/17/2011 21:23'!
testNoFieldCookieHandlerAbsent
	"There is no key in the URL but there is a cookie. However, the handler specified by key does not exist."
	
	| response context |
	registry := self createRegistryWithCookiesEnabled.
	context := self createRequestContextWithFieldKey: nil cookieKey: '123'.
	response := self dispatch: context to: registry.
	
	self assertCookieDeletion: response.
	self assertExpired: response! !

!WAApplicationKeyHandlingTest methodsFor: 'tests' stamp: 'pmm 7/17/2011 21:23'!
testNoFieldCookieHandlerPresent
	"There is no key in the URL but there is a cookie. The handler specified by key exists."
	
	| response context key |
	registry := self createRegistryWithCookiesEnabled.
	key := self registerNewHandler.
	context := self createRequestContextWithFieldKey: nil cookieKey: key.
	response := self dispatch: context to: registry.
	
	self assertNoCookies: response.
	self assertDispatched: response! !

!WAApplicationKeyHandlingTest methodsFor: 'tests' stamp: 'jf 1/30/2009 16:15'!
testNoKey
	"There is no URL field and no cookie. This is a new request to the Registry.
	
	Instead of returning a 404, like WARegistry does, WAApplication creates a new WASession
	and also adds the cookie."
	
	| response context |
	registry := self createRegistryWithCookiesEnabled.
	context := self createRequestContextWithFieldKey: nil cookieKey: nil.
	response := self dispatch: context to: registry.
	
	self assertCookieAddition: response.
	self assert: ((registry cache at: response cookies first value) isKindOf: WASession).
	self assertDefault: response! !

WAContextTest subclass: #WAInteractionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAInteractionTest commentStamp: 'pmm 2/18/2011 22:51' prior: 0!
The purpose of WAInteractionTest is to provide a fully initialized WContext all the neccsary objects are are normally there in a Seaside application like request, response, dispatcher application, session and so forth.!

!WAInteractionTest methodsFor: 'accessing' stamp: 'lr 7/25/2011 19:53'!
application
	^ self requestContext application! !

!WAInteractionTest methodsFor: 'configuration' stamp: 'lr 7/25/2011 19:53'!
createHandlers
	| dispatcher application session root |
	root := WADispatcher new.
	dispatcher := root register: WADispatcher new at: 'rails'.
	application := dispatcher register: WAApplication new at: 'homepage'.
	session := WASession new.
	application register: session.
	^ super createHandlers, (Array with: root with: dispatcher with: application with: session)! !

!WAInteractionTest methodsFor: 'accessing' stamp: 'lr 7/25/2011 19:53'!
session
	^ self requestContext session! !

!WAInteractionTest methodsFor: 'tests' stamp: 'jf 2/6/2010 00:41'!
testDeleteNetscapeCookie
	| requestCookie responseCookies responseCookie |
	self application preferenceAt: #serverPath put: '/en/private_kunden/wealth_management'.
	requestCookie := WARequestCookie key: 'password' value: 'sex'.
	self requestContextWithUrl: '/' cookies: (Array with: requestCookie).
	self requestContext response deleteCookie: requestCookie.
	
	responseCookies := self requestContext response cookies.
	self assert: responseCookies size = 1.
	responseCookie := responseCookies any.
	
	self assert: (responseCookie isKindOf: WACookie).
	self assert: responseCookie value = ''.
	self assert: responseCookie path = self application url pathString! !

!WAInteractionTest methodsFor: 'tests' stamp: 'jf 2/6/2010 00:41'!
testDeleteRfc2965Cookie
	| requestCookie responseCookies responseCookie |
	requestCookie := (WARequestCookie key: 'password' value: 'sex')
		path: '/en/private_kunden/wealth_management';
		version: 1;
		yourself.
	self requestContextWithUrl: '/' cookies: (Array with: requestCookie).
	self requestContext response deleteCookie: requestCookie.
	
	responseCookies := self requestContext response cookies.
	self assert: responseCookies size = 1.
	responseCookie := responseCookies any.
	
	self assert: (responseCookie isKindOf: WACookie).
	self assert: responseCookie value = ''.
	self assert: responseCookie path = '/en/private_kunden/wealth_management'! !

!WAInteractionTest methodsFor: 'tests' stamp: 'jf 11/3/2009 01:15'!
testNewCookie
	| cookie |
	cookie := self requestContext newCookie.
	self assert: cookie path = self application url pathString.
	self assert: cookie ports isNil.
	self assert: cookie httpOnly.
	self deny: cookie secure.
	self assert: cookie domain isNil.
	
	self application preferenceAt: #serverPath put: '/en/private_kunden/wealth_management'.
	cookie := self requestContext newCookie.
	self assert: cookie path = '/en/private_kunden/wealth_management'.
	self assert: cookie ports isNil.
	self assert: cookie httpOnly.
	self deny: cookie secure.
	self assert: cookie domain isNil.
	
	self application preferenceAt: #serverPort put: 8080.
	self application preferenceAt: #serverProtocol put: 'https'.
	self application preferenceAt: #serverHostname put: 'www.lgt.com'.
	cookie := self requestContext newCookie.
	self assert: cookie path = '/en/private_kunden/wealth_management'.
	self deny: cookie ports isNil.
	self assert: cookie ports size = 1.
	self assert: cookie ports first = 8080.
	self assert: cookie httpOnly.
	self assert: cookie secure.
	self assert: cookie domain = 'www.lgt.com'! !

WARegistryTest subclass: #WAApplicationEncodingFallbackTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAApplicationEncodingFallbackTest methodsFor: 'private' stamp: 'pmm 5/26/2010 21:26'!
newHandler
	^ WAApplication new
		preferenceAt: #charSet put: 'utf-16';
		yourself! !

!WAApplicationEncodingFallbackTest methodsFor: 'tests' stamp: 'pmm 5/26/2010 21:28'!
testContentType
	self assert: handler contentType = ('text/html' seasideMimeType
		charset: 'utf-16';
		yourself)! !

WARegistryTest subclass: #WAApplicationEncodingFromCodecTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAApplicationEncodingFromCodecTest methodsFor: 'configuration' stamp: 'pmm 5/26/2010 21:29'!
createCodec
	^ GRCodec forEncoding: 'iso-8859-1'! !

!WAApplicationEncodingFromCodecTest methodsFor: 'private' stamp: 'pmm 5/26/2010 21:30'!
newHandler
	^ WAApplication new
		preferenceAt: #charSet put: 'utf-16';
		yourself! !

!WAApplicationEncodingFromCodecTest methodsFor: 'tests' stamp: 'pmm 5/26/2010 21:29'!
testContentType
	self assert: handler contentType = ('text/html' seasideMimeType
		charset: 'iso-8859-1';
		yourself)! !

WARegistryTest subclass: #WAApplicationTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAApplicationTest class methodsFor: 'testing' stamp: 'jf 1/29/2009 20:59'!
shouldInheritSelectors
	^ true! !

!WAApplicationTest methodsFor: 'private' stamp: 'pmm 8/25/2011 15:10'!
newHandler
	^ WAApplication new
		preferenceAt: #rootClass put: WAComponent;
		yourself! !

!WAApplicationTest methodsFor: 'running' stamp: 'pmm 8/31/2009 14:05'!
requestWithMethod: aString
	^ WARequest
		method: aString
		uri: '/app/oneo'! !

!WAApplicationTest methodsFor: 'tests' stamp: 'jf 1/29/2009 21:19'!
testNotImplemented
	| context request |
	#('OPTIONS' 'HEAD' 'PUT' 'DELETE' 'TRACE' 'CONNECT') do: [ :each |
		request := self requestWithMethod: each.
		context := WARequestContext request: request response: WABufferedResponse new.
		[ handler handle: context ]
			on: WAResponseNotification
			do: [ :notification | ].
		self assert: context response status = 501 ].
	
	#('GET' 'POST') do: [ :each |
		request := self requestWithMethod: each.
		context := WARequestContext request: request response: WABufferedResponse new.
		[ handler handle: context ]
			on: WAResponseNotification
			do: [ :notification | ].
		self assert: context response status ~= 501 ]! !

!WAApplicationTest methodsFor: 'tests' stamp: 'lr 9/8/2009 19:46'!
testPathConsumption
	| context request |
	request := self requestWithMethod: 'GET'.
	context := WARequestContext request: request response: WABufferedResponse new.
	context consumer next.
	self assert: context consumer peek = 'oneo'.
	[ handler handle: context ]
		on: WAResponseNotification
		do: [ :notification | ].
	self assert: context consumer peek = 'oneo'! !

!WAApplicationTest methodsFor: 'tests' stamp: 'pmm 6/20/2011 21:11'!
testPreFetchIsForbidden
	| context request |

	request := self requestWithMethod: 'GET'.
	request headers at: 'x-moz' put: 'prefetch'. "turn it into a prefetch request"
	self assert: request isPrefetch.
		
	context := WARequestContext request: request response: WABufferedResponse new.
	[ handler handle: context ]
		on: WAResponseNotification
		do: [ :notification | "ignore" ].
	self assert: context response status = WAResponse statusForbidden.! !

WARegistryTest subclass: #WASessionCookieTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WASessionCookieTest class methodsFor: 'testing' stamp: 'pmm 8/12/2010 23:23'!
shouldInheritSelectors
	^ true! !

!WASessionCookieTest methodsFor: 'private' stamp: 'pmm 8/25/2011 15:09'!
newHandler
	^ WAApplication new
		preferenceAt: #trackingStrategy put: WACookieIfSupportedSessionTrackingStrategy new;
		preferenceAt: #serverHostname put: 'www.seaside.st';
		preferenceAt: #rootClass put: WAComponent;
		yourself! !

!WASessionCookieTest methodsFor: 'running' stamp: 'pmm 8/12/2010 23:23'!
requestWithMethod: aString
	^ WARequest
		method: aString
		uri: '/'! !

!WASessionCookieTest methodsFor: 'tests' stamp: 'pmm 8/12/2010 23:54'!
testDeleteSessionCookieDomain
	| context request response cookie |
	request := self requestWithMethod: 'GET'.
	request setCookies: (Array with: (WARequestCookie key: '_s' value: 'goner')).
	response := WABufferedResponse new.
	context := WARequestContext request: request response: response.
	[ handler handle: context ]
		on: WAResponseNotification
		do: [ :notification | ].
	self assert: response status = 302. "session gone"
	self assert: response cookies size = 1.
	cookie := response cookies first.
	self assert: cookie domain = 'www.seaside.st'! !

!WASessionCookieTest methodsFor: 'tests' stamp: 'pmm 8/12/2010 23:47'!
testNewSessionCookieDomain
	| context request response cookie |
	request := self requestWithMethod: 'GET'.
	response := WABufferedResponse new.
	context := WARequestContext request: request response: response.
	[ handler handle: context ]
		on: WAResponseNotification
		do: [ :notification | ].
	self assert: response cookies size = 1.
	cookie := response cookies first.
	self assert: cookie domain = 'www.seaside.st'! !

!WASessionCookieTest methodsFor: 'tests' stamp: 'lr 8/22/2010 15:30'!
testUrlFor
	| context request response documentHandler url |
	request := self requestWithMethod: 'GET'.
	request setCookies: (Array with: (WARequestCookie key: '_s' value: 'sessionid')).
	response := WABufferedResponse new.
	documentHandler := (WADocumentHandler
		document: 'body: {color: red}'
		mimeType: WAMimeType textCss
		fileName: nil).
	
	context := WARequestContext request: request response: response.
	url := WACurrentRequestContext
		use: context
		during: [ handler register: documentHandler;
			urlFor: documentHandler ].
	self assert: (url queryFields includesKey: '_s').
	request url addField: '_s' value: (url queryFields at: '_s').
		
	[  handler handle: context ]
		on: WAResponseNotification
		do: [ :notification | ].
		
	self assert: response status = 200.
	self assert: (response cookies isEmpty)! !

!GRPackage class methodsFor: '*seaside-tests-session' stamp: 'lr 2/17/2010 15:14'!
seasideTestsSession
	^ self new
		name: 'Seaside-Tests-Session';
		description: 'Unit tests for the package Seaside-Session.';
		addDependency: 'Seaside-Session';
		addDependency: 'Seaside-Tests-Core';
		url: #seasideUrl;
		yourself! !

WAHandlerTrackingStrategyTest subclass: #WASessionTrackingStrategyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

WASessionTrackingStrategyTest subclass: #WACookieForBrowserIPForCrawlerTrackingStrategyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WACookieForBrowserIPForCrawlerTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 8/1/2011 13:52'!
browserUserAgents
	^ #(
		'Mozilla/5.0 (X11; U; Linux i586; de; rv:5.0) Gecko/20100101 Firefox/5.0'
		'Mozilla/5.0 (Macintosh; U; Intel Mac OS X 10_6_7; da-dk) AppleWebKit/533.21.1 (KHTML, like Gecko) Version/5.0.5 Safari/533.21.1'
		'Opera/9.80 (X11; Linux x86_64; U; fr) Presto/2.9.168 Version/11.50'
		'Mozilla/5.0 (X11; Linux i686) AppleWebKit/535.1 (KHTML, like Gecko) Ubuntu/11.04 Chromium/14.0.825.0 Chrome/14.0.825.0 Safari/535.1'
		'Mozilla/5.0 (Windows; U; MSIE 9.0; Windows NT 9.0; en-US)'
		'Mozilla/5.0 (compatible; MSIE 8.0; Windows NT 5.2; Trident/4.0; Media Center PC 4.0; SLCC1; .NET CLR 3.0.04320)'
		'Mozilla/5.0 (Windows; U; MSIE 7.0; Windows NT 6.0; en-US)'
		'Mozilla/5.0 (Windows; U; MSIE 6.0; Windows NT 5.1; SV1; .NET CLR 2.0.50727)'
	)! !

!WACookieForBrowserIPForCrawlerTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 8/1/2011 13:55'!
crawlerUserAgents
	^ #(
		'Mozilla/5.0 (compatible; Googlebot/2.1; +http://www.google.com/bot.html)'
		'Googlebot/2.1 (+http://www.google.com/bot.html)'
		'Mozilla/5.0 (compatible; Yahoo!! Slurp; http://help.yahoo.com/help/us/ysearch/slurp)'
		'Mozilla/5.0 (compatible; bingbot/2.0; +http://www.bing.com/bingbot.htm)'
		'msnbot/2.1'
	)! !

!WACookieForBrowserIPForCrawlerTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 7/31/2011 14:14'!
newStrategy
	^ WACookieForBrowserIPForCrawlerTrackingStrategy new! !

!WACookieForBrowserIPForCrawlerTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 8/1/2011 13:54'!
testIsFromCrawler
	| context |
	context := self requestContext.
	self crawlerUserAgents do: [ :each |
		context request headers at: 'user-agent' put: each.
		self assert: (strategy  isFromCrawler: context) ]! !

!WACookieForBrowserIPForCrawlerTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 8/1/2011 13:54'!
testIsNotFromCrawler
	| context |
	context := self requestContext.
	self browserUserAgents do: [ :each |
		context request headers at: 'user-agent' put: each.
		self deny: (strategy  isFromCrawler: context) ]! !

WASessionTrackingStrategyTest subclass: #WACookieSessionTrackingStrategyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

WACookieSessionTrackingStrategyTest subclass: #WACookieIfSupportedSessionTrackingStrategyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WACookieIfSupportedSessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 7/17/2011 11:48'!
newStrategy
	^ WACookieIfSupportedSessionTrackingStrategy new! !

!WACookieIfSupportedSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 7/31/2011 13:45'!
testAddKeyOfSessionToUrl
	| context uri |
	context := self requestContext.
	uri := context request uri copy.
	strategy addKey: 'The_Metaphor' of: self newSession toUrl: uri.
	self assert: uri greaseString = '/1/2?_s=The_Metaphor'! !

!WACookieIfSupportedSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 7/31/2011 13:53'!
testAddKeyOfSessionToUrlCookieAlreadyPresent
	| context uri cookie1 |
	context := self requestContext.
	cookie1 := WARequestCookie key: strategy keyCookieName value: 'The_Metaphor'.
	context request setCookies: (Array with: cookie1).
	uri := context request uri copy.
	strategy addKey: 'The_Metaphor' of: self newSession toUrl: uri.
	self assert: uri greaseString = '/1/2'! !

WACookieSessionTrackingStrategyTest subclass: #WACookieOnlySessionTrackingStrategyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WACookieOnlySessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 7/17/2011 11:48'!
newStrategy
	^ WACookieOnlySessionTrackingStrategy new! !

!WACookieOnlySessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 7/31/2011 13:45'!
testAddKeyOfSessionToUrl
	| context uri |
	context := self requestContext.
	uri := context request uri copy.
	strategy addKey: 'The_Metaphor' of: self newSession toUrl: uri.
	self assert: uri greaseString = '/1/2'! !

!WACookieSessionTrackingStrategyTest class methodsFor: 'testing' stamp: 'pmm 7/17/2011 11:45'!
isAbstract
	^ self name = #WACookieSessionTrackingStrategyTest! !

!WACookieSessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 7/31/2011 13:57'!
assertNotFound: aRequestContext
	self assert: aRequestContext response status = WAResponse statusFound.
	self assert: (aRequestContext response headerAt: 'Location') = '/1/2'! !

!WACookieSessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 7/24/2011 21:37'!
createRequest
	^ WARequest method: 'GET' uri: '/1/2'! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 7/31/2011 13:37'!
testAddCookieNonePresentYet
	| context |
	context := self requestContext.
	strategy addKey: 'The_Metaphor' of: self newSession toContext: context.
	self assertCookieInContext: context withValue: 'The_Metaphor'! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 7/31/2011 13:39'!
testAddCookieOneAlreadyPresent
	| context cookie1 |
	cookie1 := WARequestCookie key: strategy keyCookieName value: 'The_Metaphor'.
	context := self requestContext.
	context request setCookies: (Array with: cookie1).
	
	strategy addKey: 'The_Metaphor' of: self newSession toContext: context.
	self assertNoCookies: context! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 7/31/2011 13:40'!
testAddCookieOneAlreadyPresentWithWrongValue
	| context cookie1 |
	cookie1 := WARequestCookie key: strategy keyCookieName value: 'The_Abstraction'.
	context := self requestContext.
	context request setCookies: (Array with: cookie1).
	
	strategy addKey: 'The_Metaphor' of: self newSession toContext: context.
	self assertCookieInContext: context withValue: 'The_Metaphor'! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 7/31/2011 13:45'!
testAddKeyOfDocumentHandlerToUrl
	| context uri |
	context := self requestContext.
	uri := context request uri copy.
	strategy addKey: 'The_Metaphor' of: self newDocumentHandler toUrl: uri.
	self assert: uri greaseString = '/1/2?_s=The_Metaphor'! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 7/31/2011 13:36'!
testAddNoCookieForDocumentHandler
	| context |
	context := self requestContext.
	strategy addKey: 'The_Metaphor' of: self newDocumentHandler toContext: context.
	self assertNoCookies: context! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 7/24/2011 21:32'!
testEmpty
	| key |
	key := strategy keyFromContext: self requestContext.
	self assert: key isNil! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 7/31/2011 13:55'!
testNoHandlerFoundForKey
	| context notified |
	context := self requestContext.
	notified := false.
	[ strategy
		noHandlerFoundForKey: 'The_Birthday_Massacre'
		in: self newApplication
		context: context. ]
		on: WAResponseNotification
		do: [ :notification | notified := true ].
	self assert: notified.
	self assertNotFound: context! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 1/22/2012 16:23'!
testOneOfMany
	| cookie1 cookie2 cookie3 cookie4 actual context |
	cookie1 := WARequestCookie key: strategy keyCookieName value: 'cookie1'.
	cookie2 := (WARequestCookie key: strategy keyCookieName value: 'cookie2')
		path: '/';
		yourself.
	cookie3 := (WARequestCookie key: strategy keyCookieName value: 'cookie3')
		path: '/1/2';
		yourself.
	cookie4 := (WARequestCookie key: strategy keyCookieName value: 'cookie4')
		path: '/1/2/3';
		yourself.
	context := self requestContext.
	context request setCookies: (Array
			with: cookie1
			with: cookie2
			with: cookie3
			with: cookie4).
	
	actual := strategy keyFromContext: context.
	self assert: actual = 'cookie3'! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 1/22/2012 16:23'!
testOneOfManySlashInCookie
	| cookie1 cookie2 cookie3 cookie4 actual context |
	cookie1 := WARequestCookie key: strategy keyCookieName value: 'cookie1'.
	cookie2 := (WARequestCookie key: strategy keyCookieName value: 'cookie2')
		path: '/';
		yourself.
	cookie3 := (WARequestCookie key: strategy keyCookieName value: 'cookie3')
		path: '/1/2/';
		yourself.
	cookie4 := (WARequestCookie key: strategy keyCookieName value: 'cookie4')
		path: '/1/2/3/';
		yourself.
	context := self requestContext.
	context request setCookies: (Array
			with: cookie1
			with: cookie2
			with: cookie3
			with: cookie4).
	actual := strategy keyFromContext: context.
	self assert: actual = 'cookie3'! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 1/22/2012 16:23'!
testOneOfManySlashInUrl
	| cookie1 cookie2 cookie3 cookie4 actual context |
	cookie1 := WARequestCookie key: strategy keyCookieName value: 'cookie1'.
	cookie2 := (WARequestCookie key: strategy keyCookieName value: 'cookie2')
		path: '/';
		yourself.
	cookie3 := (WARequestCookie key: strategy keyCookieName value: 'cookie3')
		path: '/1/2';
		yourself.
	cookie4 := (WARequestCookie key: strategy keyCookieName value: 'cookie4')
		path: '/1/2/3';
		yourself.
	context := self requestContext.
	context request setCookies: (Array
			with: cookie1
			with: cookie2
			with: cookie3
			with: cookie4).
	actual := strategy keyFromContext: context.
	self assert: actual = 'cookie3'! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 1/22/2012 16:23'!
testOnlyOne
	| cookie1 key context |
	cookie1 := WARequestCookie key: strategy keyCookieName value: 'cookie1'.
	context := self requestContext.
	context request setCookies: (Array with: cookie1).
	
	key := strategy keyFromContext: context.
	self assert: key = 'cookie1'! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 1/22/2012 16:23'!
testQueryFieldOverridesCookie
	| cookie1 key context |
	cookie1 := WARequestCookie key: strategy keyCookieName value: 'cookie1'.
	context := self requestContext.
	context request setCookies: (Array with: cookie1).
	context request uri addField: strategy keyField value: 'value1'. 
	
	key := strategy keyFromContext: context.
	self assert: key = 'value1'! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 1/22/2012 16:23'!
testWrongKey
	| cookie context actual |
	cookie := WARequestCookie key: (strategy keyCookieName, '-not') value: 'cookie'.
	context := self requestContext.
	context request setCookies: (Array with: cookie).
	actual := strategy keyFromContext: context.
	self assert: actual isNil! !

!WACookieSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 1/22/2012 16:23'!
testWrongPrefix
	| cookie1 cookie2 actual context |
	cookie1 := WARequestCookie key: strategy keyCookieName value: 'cookie1'.
	cookie2 := (WARequestCookie key: strategy keyCookieName value: 'cookie2')
		path: '/one';
		yourself.

	context := self requestContext.
	context request setCookies: (Array
			with: cookie1
			with: cookie2).
	actual := strategy keyFromContext: context.
	self assert: actual = 'cookie1'! !

WASessionTrackingStrategyTest subclass: #WAInvisibleSessionTrackingStrategyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

WAInvisibleSessionTrackingStrategyTest subclass: #WAIPSessionTrackingStrategyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAIPSessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 7/31/2011 14:11'!
createRequest
	^ super createRequest
		setRemoteAddress: self remoteAddress;
		yourself! !

!WAIPSessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 7/31/2011 14:02'!
newStrategy
	^ WAIPSessionTrackingStrategy new! !

!WAIPSessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 7/31/2011 14:11'!
remoteAddress
	^ '17.154.81.95'! !

!WAIPSessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 8/14/2011 11:19'!
sessionId
	^ self remoteAddress! !

!WAInvisibleSessionTrackingStrategyTest class methodsFor: 'testing' stamp: 'pmm 8/14/2011 11:16'!
isAbstract
	^ self name = #WAInvisibleSessionTrackingStrategyTest! !

!WAInvisibleSessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 8/14/2011 11:19'!
sessionId
	self subclassResponsibility! !

!WAInvisibleSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 8/14/2011 11:13'!
testAddKeyOfDocumentHandlerToContext
	| context |
	context := self requestContext.
	strategy addKey: 'The_Metaphor' of: self newDocumentHandler toContext: context.
	self assertNoCookies: context! !

!WAInvisibleSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 8/14/2011 11:13'!
testAddKeyOfDocumentHandlerToUrl
	| context uri |
	context := self requestContext.
	uri := context request uri copy.
	strategy addKey: 'The_Metaphor' of: self newDocumentHandler toUrl: uri.
	self assert: uri greaseString = '/catspajamassc2?_s=The_Metaphor'! !

!WAInvisibleSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 8/14/2011 11:13'!
testAddKeyOfSessionToContext
	| context |
	context := self requestContext.
	strategy addKey: 'The_Metaphor' of: self newSession toContext: context.
	self assertNoCookies: context! !

!WAInvisibleSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 8/14/2011 11:13'!
testAddKeyOfSessionToUrl
	| context uri |
	context := self requestContext.
	uri := context request uri copy.
	strategy addKey: 'The_Metaphor' of: self newSession toUrl: uri.
	self assert: uri greaseString = '/catspajamassc2'! !

!WAInvisibleSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 1/22/2012 16:23'!
testKeyFromIpAddress
	| context actual |
	context := self requestContext.
	actual := strategy keyFromContext: context.
	self assert: actual = self sessionId! !

!WAInvisibleSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 1/22/2012 16:23'!
testKeyFromQueryField
	| context actual |
	context := self requestContext.
	context request uri addField: strategy keyField value: '4e232e46-003d2-04324-d3ac8fa8'.
	actual := strategy keyFromContext: context.
	self assert: actual = '4e232e46-003d2-04324-d3ac8fa8'! !

!WAInvisibleSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 8/14/2011 11:13'!
testNoHandlerFoundForDocumentHandlerKey
	| context notified |
	context := self requestContext.
	strategy
		addKey: 'The_Birthday_Massacre'
		of: self newSession
		toUrl: context request uri copy.
	notified := false.
	[ strategy
		noHandlerFoundForKey: 'The_Birthday_Massacre'
		in: self newApplication
		context: context. ]
		on: WAResponseNotification
		do: [ :notification | notified := true ].
	self assert: notified.
	self assertNotFound: context! !

!WAInvisibleSessionTrackingStrategyTest methodsFor: 'testing' stamp: 'pmm 8/25/2011 16:47'!
testNoHandlerFoundForSessionKey
	| context application cache session |
	context := self requestContext.
	application := self newApplication.
	[ strategy
		noHandlerFoundForKey: self sessionId
		in: application
		context: context. ]
		on: WAResponseNotification
		do: [ :notification | "ignore" ].
	self assertOk: context.
	cache := application cache.
	self assert: cache size = 1.
	session := cache at: self sessionId ifAbsent: [ nil ].
	self deny: session isNil.
	self assert: session isSession.! !

WAInvisibleSessionTrackingStrategyTest subclass: #WASslSessionTrackingStrategyTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WASslSessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 8/14/2011 11:18'!
createRequest
	^ super createRequest
		setSslSessionId: self sslSessionId;
		yourself! !

!WASslSessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 8/14/2011 11:17'!
newStrategy
	^ WASslSessionTrackingStrategy new! !

!WASslSessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 1/22/2012 16:14'!
sessionId
	^ self sslSessionId! !

!WASslSessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 8/14/2011 11:18'!
sslSessionId
	^ 'F42BAA17C89C707060E6BF5D251CC7E8832117056C1A8B0883387CA0EDDB52CF'! !

WASessionTrackingStrategyTest subclass: #WAQueryFieldHandlerTrackingStrategySessionTest
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WAQueryFieldHandlerTrackingStrategySessionTest commentStamp: 'pmm 7/24/2011 21:00' prior: 0!
I test all the session related behavior of WAQueryFieldHandlerTrackingStrategy that can't be tested in WAQueryFieldHandlerTrackingStrategyTest for dependency reasons.!

!WAQueryFieldHandlerTrackingStrategySessionTest methodsFor: 'private' stamp: 'pmm 7/24/2011 20:56'!
newStrategy
	^ WAQueryFieldHandlerTrackingStrategy new! !

!WAQueryFieldHandlerTrackingStrategySessionTest methodsFor: 'testing' stamp: 'pmm 7/24/2011 21:27'!
testAddKeyToContext
	| context |
	context := self requestContext.
	strategy addKey: 'The_Metaphor' of: self newSession toContext: context.
	self assertNoCookies: context! !

!WAQueryFieldHandlerTrackingStrategySessionTest methodsFor: 'testing' stamp: 'pmm 7/24/2011 21:27'!
testAddKeyToUrl
	| context uri |
	context := self requestContext.
	uri := context request uri copy.
	strategy addKey: 'The_Metaphor' of: self newSession toUrl: uri.
	self assert: uri greaseString = '/catspajamassc2?_s=The_Metaphor'! !

!WAQueryFieldHandlerTrackingStrategySessionTest methodsFor: 'testing' stamp: 'pmm 7/24/2011 21:28'!
testNoHandlerFoundForKey
	| context notified |
	context := self requestContext.
	notified := false.
	[ strategy
		noHandlerFoundForKey: 'The_Birthday_Massacre'
		in: self newApplication
		context: context. ]
		on: WAResponseNotification
		do: [ :notification | notified := true ].
	self assert: notified.
	self assertNotFound: context! !

!WASessionTrackingStrategyTest class methodsFor: 'testing' stamp: 'pmm 7/24/2011 21:13'!
isAbstract
	^ self name = #WASessionTrackingStrategyTest! !

!WASessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 7/24/2011 21:32'!
assertNotFound: aRequestContext
	self assert: aRequestContext response status = WAResponse statusFound.
	self assert: (aRequestContext response headerAt: 'Location') = '/catspajamassc2'! !

!WASessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 7/31/2011 14:49'!
assertOk: aRequestContext
	self assert: aRequestContext response status = WAResponse statusOk! !

!WASessionTrackingStrategyTest methodsFor: 'configuration' stamp: 'pmm 7/24/2011 21:19'!
createHandlers
	^ Array with: self newApplication! !

!WASessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 8/25/2011 15:11'!
newApplication
	^ WAApplication new
		preferenceAt: #rootClass put: WAComponent;
		yourself! !

!WASessionTrackingStrategyTest methodsFor: 'private' stamp: 'pmm 7/24/2011 20:54'!
newSession
	^ WASession new! !

WASession subclass: #WATestSession
	instanceVariableNames: ''
	classVariableNames: ''
	poolDictionaries: ''
	category: 'Seaside-Tests-Session'!

!WATestSession methodsFor: 'handling' stamp: 'lr 2/16/2010 20:53'!
start
	(self requestContext response)
		nextPutAll: 'start: ';
		nextPutAll: self key! !
